-----------------------------------------------------------------------------
--
-- data
--   \dispel
--     \<playerName>
--       - count
--
-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AssessmentDispel")
L:RegisterTranslations("enUS", function() return {
	["Dispellers List"] = true,
	["Dispels"] = true,
} end)

-----------------------------------------------------------------------------

local AssessmentDispel = Assessment:NewModule("Dispellers", "AceEvent-2.0", "Parser-3.0")
AssessmentDispel.db = Assessment:AcquireDBNamespace("Dispellers")
Assessment:RegisterDefaults("Dispellers", "profile", {
	enable = true
})

-----------------------------------------------------------------------------

Assessment.TagData.dispelcount =
{
	method = function(data)
				local fightData = data.fightData
				if not fightData then return 0 end
				
				local dispel = fightData.dispel
				if not dispel then return 0 end
				
				if not dispel[data.key] then return 0 end
				return dispel[data.key].count
			 end,
	data = "dispel",
	guaranteeResult = true,
	numeric = true,
}

-----------------------------------------------------------------------------

Assessment.ListType.Dispellers =
{
	method = function(fightData)
				if not fightData.dispel then return function() return nil end, nil, nil end
				return pairs(fightData.dispel)
			 end,
	data = "dispel",
	description = L["Dispellers List"],
}

-----------------------------------------------------------------------------

Assessment.DefaultDisplaySets.Dispels =
{
	titleTag		= "Dispels",
	listType		= "Dispellers", 
	barValueTag		= "dispelCount", 
	filterType		= "NONZERO",
	fightIndex		= 0,
	barValueTextTag	= "[barValue]",
	description		= L["Dispels"],
}

-----------------------------------------------------------------------------

function AssessmentDispel:OnInitialize()
end

function AssessmentDispel:OnEnable()
	self:RegisterParserEvent({ eventType = "Dispel" }, "OnParserDispelEvent")
end

function AssessmentDispel:OnDisable()
end

-----------------------------------------------------------------------------

function AssessmentDispel:OnParserDispelEvent(eventData)
	if eventData.isFailed then return end

	for data in self:IterateUpdateDataTables() do
		data.dataUpdateTimes.dispel = GetTime()
		local dispel = data.dispel
		if not dispel then
			dispel = self:NewTable()
			data.dispel = dispel
		end

		local playerDispel = dispel[eventData.sourceName]
		if playerDispel then
			playerDispel.count = playerDispel.count + 1
		else
			playerDispel = self:NewTable()
			playerDispel.count = 1
			dispel[eventData.sourceName] = playerDispel
		end
	end
end

-----------------------------------------------------------------------------
