-----------------------------------------------------------------------------

local Roster = AceLibrary("Roster-2.1")

-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AssessmentGroupMembers")
L:RegisterTranslations("enUS", function() return {
	["Group Members"] = true,
	["Current Group Members"] = true,
	["Show Group Members"] = true,
	["Show Non-Group Members"] = true,
    ["Class"] = true,
} end)

-----------------------------------------------------------------------------

Assessment.ListType.GroupMembers = 
{
	method = function(fightData) return pairs(fightData.groupMembers) end,
	data = "groupMembers",
	description = L["Group Members"],
}

local groupMemberNameList = { }
Assessment.ListType.CurrentGroupMembersAndPets = 
{
	method = function(fightData)
				for k in pairs(groupMemberNameList) do
					groupMemberNameList[k] = nil
				end
				
				for unit in Roster:IterateRoster(true) do
					groupMemberNameList[unit.name] = true
				end
				
				return pairs(groupMemberNameList)
			 end,
	data = "groupMembers",
	description = L["Current Group Members"],
}

-----------------------------------------------------------------------------

Assessment.FilterType.GroupMembers =
{
	method		= function(data) return Roster:GetUnitIDFromName(data.key) end,
	description = L["Show Group Members"]
}

-----------------------------------------------------------------------------

Assessment.FilterType.NonGroupMembers =
{
	method		= function(data) return not Roster:GetUnitIDFromName(data.key) end,
	description = L["Show Non-Group Members"]
}

-----------------------------------------------------------------------------

local classColors = { }

for k,v in pairs(RAID_CLASS_COLORS) do
	classColors[k] = { v.r, v.g, v.b }
end

-----------------------------------------------------------------------------

Assessment.ColorType.Class = 
{
	method = function(fightData, key)
				local class = fightData.groupMembers[key]
				if not class then return nil end
				return classColors[class]
			 end,
	data = "groupMembers",
	description = L["Class"]
}

-----------------------------------------------------------------------------

local AssessmentGroupMembers = Assessment:NewModule("GroupMembers", "AceEvent-2.0")

function AssessmentGroupMembers:OnEnable()
	self:RegisterEvent("RosterLib_RosterUpdated", "OnRosterUpdated")
	self:RegisterEvent("Assessment:NewFightDataTable", "OnNewFightDataTable")
end

function AssessmentGroupMembers:OnRosterUpdated()
	for data in self:IterateUpdateDataTables() do
		data.dataUpdateTimes.groupMembers = GetTime()

		local groupMembers = data.groupMembers
		for unit in Roster:IterateRoster(true) do
			groupMembers[unit.name] = unit.class
		end
	end
end

function AssessmentGroupMembers:OnNewFightDataTable(data)
	data.dataUpdateTimes.groupMembers = GetTime()
	
	local groupMembers = self:NewTable()
	data.groupMembers = groupMembers

	for unit in Roster:IterateRoster(true) do
		groupMembers[unit.name] = unit.class
	end
end

-----------------------------------------------------------------------------
